
var Spaceship = {
    file: 'gfx/Spaceship.png',
    
    init: function() {
        this.sprite = PIXI.Sprite.from(this.file);
        this.sprite.anchor.set(0.5);
        this.sprite.x = 100;
        this.sprite.y = 100;
    },
    
    acceleration: 350.0,
    deceleration: 250.0,
    maximum_velocity: 450.0,
    velocity_x: 0.0,
    velocity_y: 0.0,
    velocity_turn: 0.0,
    velocity_turn_acceleration: 2.5,
    velocity_turn_deceleration: 5.0,
    maximum_turn_velocity: 5.0,
    turning: 'no',
    movement: 'no',
    
    
    update: function(delta) {
        // Handle turning
        switch (this.turning) {
            case 'right':
                this.velocity_turn += this.velocity_turn_acceleration / 60 * delta;
                break;
            case 'left':
                this.velocity_turn -= this.velocity_turn_acceleration / 60 * delta;
                break;
            case 'none':
                if (this.velocity_turn < 0) this.velocity_turn += Math.min(this.velocity_turn_deceleration / 60 * delta, Math.abs(this.velocity_turn));
                if (this.velocity_turn > 0) this.velocity_turn -= Math.min(this.velocity_turn_deceleration / 60 * delta, Math.abs(this.velocity_turn));
                break;
        }

        // Limit turn
        if (this.velocity_turn > this.maximum_turn_velocity) this.velocity_turn = this.maximum_turn_velocity;
        if (this.velocity_turn < -this.maximum_turn_velocity) this.velocity_turn = -this.maximum_turn_velocity;
        

        // Handle moving
        var old_velocity_x = this.velocity_x;
        var old_velocity_y = this.velocity_y;
        
        switch (this.movement) {
            case 'accelerate':
                this.velocity_x += Math.sin(this.sprite.rotation) / 60 * delta * this.acceleration;
                this.velocity_y -= Math.cos(this.sprite.rotation) / 60 * delta * this.acceleration;
                break;
            case 'decelerate':
                this.velocity_x -= Math.sin(this.sprite.rotation) / 60 * delta * this.deceleration;
                this.velocity_y += Math.cos(this.sprite.rotation) / 60 * delta * this.deceleration;
                break;
            case 'none':
                break;
        }
        
        // Limit speed
        var speed = Math.sqrt(Math.pow(this.velocity_x,2)+Math.pow(this.velocity_y,2));
        if (speed > this.maximum_velocity) {
            this.velocity_x = old_velocity_x;
            this.velocity_y = old_velocity_y;
        }
        
        // Stop if very slow
        if (speed < 2 && this.movement == 'none') {
            this.velocity_x = 0;
            this.velocity_y = 0;
        }

        
        // Now apply to spaceship
        this.sprite.rotation += this.velocity_turn / 60 * delta;
        this.sprite.x += this.velocity_x / 60 * delta;
        this.sprite.y += this.velocity_y / 60 * delta;
    }
}